==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/NonStd/NonStdGetPID.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NonStdGetPID_46getPID_35	((void*)startLabel+8)
#define CT_v163	((void*)startLabel+32)
#define F0_NonStdGetPID_46getPID_35	((void*)startLabel+40)
#define CT_v167	((void*)startLabel+120)
#define ST_v160	((void*)startLabel+156)
#define ST_v165	((void*)startLabel+172)
#define PP_NonStdGetPID_46getPID_35	((void*)startLabel+192)
#define PC_NonStdGetPID_46getPID_35	((void*)startLabel+192)
#define ST_v162	((void*)startLabel+192)
#define PS_v166	((void*)startLabel+216)
#define PS_v164	((void*)startLabel+228)
#define PS_v161	((void*)startLabel+240)
void FR_NonStdGetPID_46getPID_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok0[];
extern Node PC_NHC_46Internal_46_95mkIOok0[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v163)
,	/* FN_NonStdGetPID_46getPID_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NonStdGetPID_46getPID_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v162)
,	/* CT_v163: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NonStdGetPID_46getPID_35: (byte 0) */
  CAPTAG(useLabel(FN_NonStdGetPID_46getPID_35),1)
, useLabel(PS_v161)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v167)
,};
Node FN_NonStdGetPID_46getPID[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v166)
, 0
, 0
, 0
, 0
, 50034
, useLabel(ST_v165)
,	/* CT_v167: (byte 0) */
  HW(2,0)
, 0
,};
Node CF_NonStdGetPID_46getPID[] = {
  VAPTAG(useLabel(FN_NonStdGetPID_46getPID))
, useLabel(PS_v164)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok0))
, useLabel(F0_NonStdGetPID_46getPID_35)
,};
Node PM_NonStdGetPID[] = {
 	/* ST_v160: (byte 0) */
  bytes2word(78,111,110,83)
, bytes2word(116,100,71,101)
, bytes2word(116,80,73,68)
, bytes2word(0,0,0,0)
,};
Node PP_NonStdGetPID_46getPID[] = {
 };
Node PC_NonStdGetPID_46getPID[] = {
 	/* ST_v165: (byte 0) */
  bytes2word(78,111,110,83)
, bytes2word(116,100,71,101)
, bytes2word(116,80,73,68)
, bytes2word(46,103,101,116)
,	/* PP_NonStdGetPID_46getPID_35: (byte 4) */
 	/* PC_NonStdGetPID_46getPID_35: (byte 4) */
 	/* ST_v162: (byte 4) */
  bytes2word(80,73,68,0)
, bytes2word(78,111,110,83)
, bytes2word(116,100,71,101)
, bytes2word(116,80,73,68)
, bytes2word(46,103,101,116)
, bytes2word(80,73,68,35)
, bytes2word(0,0,0,0)
,	/* PS_v166: (byte 0) */
  useLabel(PM_NonStdGetPID)
, useLabel(PP_NonStdGetPID_46getPID)
, useLabel(PC_NHC_46Internal_46_95mkIOok0)
,	/* PS_v164: (byte 0) */
  useLabel(PM_NonStdGetPID)
, useLabel(PP_NonStdGetPID_46getPID)
, useLabel(PC_NonStdGetPID_46getPID)
,	/* PS_v161: (byte 0) */
  useLabel(PM_NonStdGetPID)
, useLabel(PP_NonStdGetPID_46getPID_35)
, useLabel(PC_NonStdGetPID_46getPID_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getPID" NonStdGetPID.getPID# 1 :: Prelude.() -> Prelude.Int */
extern HsInt hs_getPID(void);
#ifdef PROFILE
static SInfo pf_hs_getPID = {"NonStdGetPID","NonStdGetPID.getPID#","Prelude.Int"};
#endif
C_HEADER(FR_NonStdGetPID_46getPID_35) {
  NodePtr nodeptr;
  HsInt result;
  /* void arg1 */;

  result = hs_getPID();

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_getPID);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/NonStd/NonStdGetPID.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NonStdGetPID_46getPID_35	((void*)startLabel+8)
#define CT_v175	((void*)startLabel+32)
#define F0_NonStdGetPID_46getPID_35	((void*)startLabel+40)
#define CT_v179	((void*)startLabel+120)
#define ST_v172	((void*)startLabel+156)
#define ST_v177	((void*)startLabel+172)
#define PP_NonStdGetPID_46getPID_35	((void*)startLabel+192)
#define PC_NonStdGetPID_46getPID_35	((void*)startLabel+192)
#define ST_v174	((void*)startLabel+192)
#define PS_v178	((void*)startLabel+216)
#define PS_v176	((void*)startLabel+228)
#define PS_v173	((void*)startLabel+240)
void FR_NonStdGetPID_46getPID_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok0[];
extern Node PC_NHC_46Internal_46_95mkIOok0[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v175)
,	/* FN_NonStdGetPID_46getPID_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NonStdGetPID_46getPID_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50001
, useLabel(ST_v174)
,	/* CT_v175: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NonStdGetPID_46getPID_35: (byte 0) */
  CAPTAG(useLabel(FN_NonStdGetPID_46getPID_35),1)
, useLabel(PS_v173)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v179)
,};
Node FN_NonStdGetPID_46getPID[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v178)
, 0
, 0
, 0
, 0
, 50001
, useLabel(ST_v177)
,	/* CT_v179: (byte 0) */
  HW(2,0)
, 0
,};
Node CF_NonStdGetPID_46getPID[] = {
  VAPTAG(useLabel(FN_NonStdGetPID_46getPID))
, useLabel(PS_v176)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok0))
, useLabel(F0_NonStdGetPID_46getPID_35)
,};
Node PM_NonStdGetPID[] = {
 	/* ST_v172: (byte 0) */
  bytes2word(78,111,110,83)
, bytes2word(116,100,71,101)
, bytes2word(116,80,73,68)
, bytes2word(0,0,0,0)
,};
Node PP_NonStdGetPID_46getPID[] = {
 };
Node PC_NonStdGetPID_46getPID[] = {
 	/* ST_v177: (byte 0) */
  bytes2word(78,111,110,83)
, bytes2word(116,100,71,101)
, bytes2word(116,80,73,68)
, bytes2word(46,103,101,116)
,	/* PP_NonStdGetPID_46getPID_35: (byte 4) */
 	/* PC_NonStdGetPID_46getPID_35: (byte 4) */
 	/* ST_v174: (byte 4) */
  bytes2word(80,73,68,0)
, bytes2word(78,111,110,83)
, bytes2word(116,100,71,101)
, bytes2word(116,80,73,68)
, bytes2word(46,103,101,116)
, bytes2word(80,73,68,35)
, bytes2word(0,0,0,0)
,	/* PS_v178: (byte 0) */
  useLabel(PM_NonStdGetPID)
, useLabel(PP_NonStdGetPID_46getPID)
, useLabel(PC_NHC_46Internal_46_95mkIOok0)
,	/* PS_v176: (byte 0) */
  useLabel(PM_NonStdGetPID)
, useLabel(PP_NonStdGetPID_46getPID)
, useLabel(PC_NonStdGetPID_46getPID)
,	/* PS_v173: (byte 0) */
  useLabel(PM_NonStdGetPID)
, useLabel(PP_NonStdGetPID_46getPID_35)
, useLabel(PC_NonStdGetPID_46getPID_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getPID" NonStdGetPID.getPID# 1 :: Prelude.() -> Prelude.Int */
extern HsInt hs_getPID(void);
#ifdef PROFILE
static SInfo pf_NonStdGetPID_46getPID_35 = {"NonStdGetPID","NonStdGetPID.getPID#","Prelude.Int"};
#endif
C_HEADER(FR_NonStdGetPID_46getPID_35) {
  NodePtr nodeptr;
  HsInt result;
  /* void arg1 */;

  result = hs_getPID();

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NonStdGetPID_46getPID_35);
  C_RETURN(nodeptr);
}
